#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "configureWPSWidgets.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       [ -remove ]"
  print
  print "Configure or remove the WebSphere Process Server v7.0 feature pack human task administration"
  print "widgets on the Business Space instance of server <serverName> on node <nodeName> or of"
  print "cluster <clusterName>."
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
  print
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
print "Starting configuration of HumanTaskAdministrationWidgets."

localNode = System.getProperty("local.node")

argerr      = None
nodeName    = localNode
clusterName = None
serverName  = None
action      = "add"

# special case: if this is a standalone profile with but one application server, then use this one
if AdminConfig.showAttribute(AdminConfig.getid(Scope().getCell()), "cellType") == "STANDALONE":
  servers = wsadminToList(AdminConfig.list("Server"))
  if len(servers) == 1 and AdminConfig.showAttribute(servers[0], "serverType") == "APPLICATION_SERVER":
    serverName = AdminConfig.showAttribute(servers[0], "name")
  #endif
#endif

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-remove"):
    action = "remove"
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if not argerr:
  if (serverName != None) + (clusterName != None) != 1:
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
#endIf

if argerr:
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.listApplications("BSpaceEAR*"):

  print "Business Space is not configured on " + scope.displayName() + ", nothing to do."

else:

  hwmWidgets = os.path.join(System.getProperty("was.install.root"), "BusinessSpace/widgets/bpmfep/Widgets_HumanTaskAdministrationWidgets.zip")
  if not os.path.isfile(hwmWidgets):
    usage("Widgets file " + hwmWidgets + " not found.")
    sys.exit(1)
  #endif

  if action == "add":
    if scope.listApplications("HumanTaskAdministrationWidgets*"):
      print "HumanTaskAdministrationWidgets already installed on " + scope.displayName() + ", nothing to do."
    else:
      print "Installing HumanTaskAdministrationWidgets on " + scope.displayName() + "."
      AdminTask.installBusinessSpaceWidgets(scope.asParameterList(["-widgets", hwmWidgets]))
    #endif
  else:
    if not scope.listApplications("HumanTaskAdministrationWidgets*"):
      print "HumanTaskAdministrationWidgets not installed on " + scope.displayName() + ", nothing to do."
    else:
      print "Uninstalling HumanTaskAdministrationWidgets on " + scope.displayName() + "."
      AdminTask.uninstallBusinessSpaceWidgets(scope.asParameterList(["-widgets", hwmWidgets]))
    #endif
  #endif

#endif

print "Done."
